<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>ფილტრი:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>აირჩიეთ ტერმინალის ფონტი</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>ფონტი:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>ზომა:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>მინიატურა</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>სანიშნეები</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>დააჭირეთ ღილაკს &quot;%1&quot; ტერმინალის დასანახად.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;შემდეგი ჩანართი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;წინა ჩანართი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Move Tab &amp;Left</source>
        <translation>ჩანართის &amp;მარცხნივ გადატანა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Move Tab &amp;Right</source>
        <translation>ჩანართის მა&amp;რჯვნივ გადატანა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>ა&amp;ქტიური ტერმინალის გასუფთავება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Keep window open when it loses focus</source>
        <translation>ფანჯრის ღიად დატოვება მას შემდეგაც კი, რაც ის ფოკუსს დაკარგავს</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;წინა ჩანართი ისტორიაში</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;შემდეგი ჩანართი ისტორიაში</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Tab</source>
        <translation>ჩანართი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Go to</source>
        <translation>გადასვლა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Split &amp;View Top-Bottom</source>
        <translation>ხედის გაყოფა ზემოდან-ქ&amp;ვემოთ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Split Vie&amp;w Left-Right</source>
        <translation>ხედის გაყოფა მარცხ&amp;ნიდან მარჯვნივ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>&amp;Close Subterminal</source>
        <translation>ქვეტერმინალის &amp;დახურვა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;ზედა ქვეტერმინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;ქვედა ქვეტერმინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;მარცხენა ქვეტერმინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>R&amp;ight Subterminal</source>
        <translation>მარ&amp;ჯვენა ქვეტერმინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Copy &amp;Selection</source>
        <translation>მონიშნულის &amp;კოპირება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Paste Clip&amp;board</source>
        <translation>&amp;ბუფერის ჩასმა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>Paste S&amp;election</source>
        <translation>მ&amp;ონიშნულის ჩასმა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Zoom &amp;in</source>
        <translation>გად&amp;იდება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;დაპატარავება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Zoom rese&amp;t</source>
        <translation>გადიდების ჩამო&amp;ყრა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>&amp;Find...</source>
        <translation>ძ&amp;ებნა...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Handle history...</source>
        <translation>ისტორიის დამუშავება...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>&amp;Save Session</source>
        <translation>სესიის &amp;შენახვა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;Load Session</source>
        <translation>სესიის &amp;ჩატვირთვა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>&amp;Toggle Menu</source>
        <translation>მენიუს &amp;გადართვა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Rename session</source>
        <translation>სესიის სახელის გადარქმევა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Tab</source>
        <translation>&amp;ახალი ჩანართი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>New Tab From &amp;Preset</source>
        <translation>ახალი ჩანართი &amp;პრესეტიდან</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;ტერმინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;ჰორიზონტალური ტერმინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;ვერტიკალური ტერმინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 ტერმ&amp;ინალი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;ჩანართის დახურვა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>&amp;New Window</source>
        <translation>&amp;ახალი ფანჯარა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;გამართვა...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>&amp;Quit</source>
        <translation>გამოსვლა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>&amp;Hide Window Borders</source>
        <translation>ფანჯრის &amp;საზღვრების დამალვა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Show Tab Bar</source>
        <translation>ჩანართების პანელი&amp;ს ჩვენება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Fullscreen</source>
        <translation>სრულ ეკრანზე</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Toggle Bookmarks</source>
        <translation>სანიშნეების გადართვა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>&amp;Bottom</source>
        <translation>ქ&amp;ვედა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>&amp;Top</source>
        <translation>&amp;ზედა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>&amp;Right</source>
        <translation>მარჯვენა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>&amp;Left</source>
        <translation>მარ&amp;ცხნივ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;ჩანართების განლაგება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>&amp;None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;ჩოჩიის განლაგება</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;ბლოკი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;ხაზგასმული</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;IBeam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;კლავიატურის კურსორის ფორმა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>A process is running.</source>
        <translation>პროცესი გაშვებულია.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Exit QTerminal</source>
        <translation>QTerminal--დან გასვლა</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Are you sure you want to exit?</source>
        <translation>დარწმუნებული ბრძანდებით, რომ გნებავთ, გახვიდეთ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>About</source>
        <translation>შესახებ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>მსუბუქი და მძლავრი მრავალპლატფორმული ტერმინალის ემულატორი</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Copyright (C) </source>
        <translation>საავტორო უფლებები დაცულია (c) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>2013-2025</source>
        <translation>2013-2025</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>LXQt Project</source>
        <translation>პროექტი LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>Development: </source>
        <translation>პროგრამირება: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>ტერმინალის მორგება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>გარეგნობა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="38"/>
        <location filename="../forms/propertiesdialog.ui" line="729"/>
        <source>Behavior</source>
        <translation>ქცევა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>მალსახმობი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="56"/>
        <source>Dropdown</source>
        <translation>ჩამოსაშლელი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="65"/>
        <source>Bookmarks</source>
        <translation>სანიშნეები</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="556"/>
        <source>Hide tab bar with only one tab</source>
        <translation>ჩანართების პანელის დამალვა, როცა, მხოლოდ, ერთი ჩანართი არსებობს</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="181"/>
        <source>Color scheme</source>
        <translation>ფერების სქემა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="207"/>
        <source>Scrollbar position</source>
        <translation>ჩოჩიის მდებარეობა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="370"/>
        <source>Start with preset:</source>
        <translation>გაშვება პრესეტით:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="287"/>
        <source>Terminal transparency</source>
        <translation>ტერმინალის გამჭვირვალობა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>None (single terminal)</source>
        <translation>არცერთი (ერთი ტერმინალი)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="386"/>
        <source>2 terminals horizontally</source>
        <translation>2 ტერმინალი ჰორიზონტალურად</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="391"/>
        <source>2 terminals vertically</source>
        <translation>2 ტერმინალი ვერტიკალურად</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="396"/>
        <source>4 terminals</source>
        <translation>4 ტერმინალი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="297"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="135"/>
        <source>Font</source>
        <translation>ფონტი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="171"/>
        <source>&amp;Change...</source>
        <translation>შე&amp;ცვლა...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>Tabs position</source>
        <translation>ჩანართების პოზიცია</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Widget style</source>
        <translation>ვიჯეტის სტილი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="512"/>
        <source>Show the menu bar</source>
        <translation>მენიუს პანელის ჩვენება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="233"/>
        <source>Cursor shape</source>
        <translation>კურსორის ფორმა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="270"/>
        <source>Enable bi-directional text support</source>
        <translation>ორმხრივი ტექსტის მხარდაჭერის ჩართვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="313"/>
        <source>Background image:</source>
        <translation>ფონის გამოსახულება:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Select</source>
        <translation>არჩევა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="263"/>
        <source>Show terminal size on resize</source>
        <translation>ტერმინალის ზომის ჩვენება ზომის შეცვლისას</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="563"/>
        <source>Fixed tab width:</source>
        <translation>მუდმივი ჩანართის სიგანე:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="414"/>
        <location filename="../forms/propertiesdialog.ui" line="573"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="536"/>
        <source>Show close button on each tab</source>
        <translation>ჩანართებზე დახურვის ღილაკის ჩვენება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Terminal margin</source>
        <translation>ტერმინალის მინდორი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="280"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>ფონტში არსებული სახატავი სიმბოლოების გამოყენება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="519"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>მალსახმობები Alt ღილაკით აქტიურდება და შეუძლია, ტერმინალის მუშაობაში ჩაერიოს.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="522"/>
        <source>No menu bar accelerator</source>
        <translation>მენიუს ამაჩქრებლების გამორთვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="922"/>
        <source>Emulation</source>
        <translation>ემულაცია</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Action after paste</source>
        <translation>ქმედება ჩასმის შემდეგ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="828"/>
        <source>Confirm multiline paste</source>
        <translation>ერთზე მეტი ჩასმის დადასტურება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="835"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>ბოლოში მოყოლილი ახალი ხაზების წაჭრა ჩასმულ ტექსტში</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="849"/>
        <source>Open new terminals in current working directory</source>
        <translation>ახალი ტერმინალების გახსნა მიმდინარე სამუშაო საქაღალდეში</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="590"/>
        <source>Save Size when closing</source>
        <translation>ზომის შენახვა დახურვისას</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="583"/>
        <source>Save Position when closing</source>
        <translation>მდებარეობის შენახვა დახურვისას</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Unlimited history</source>
        <translation>ულიმიტო ისტორია</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="735"/>
        <source>History size (in lines)</source>
        <translation>ისტორიის ზომა (ხაზებში)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="873"/>
        <source>Default $TERM</source>
        <translation>ნაგულისხმევი $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="609"/>
        <source>Start with this size:</source>
        <translation>დაწყება ამ ზომით:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="334"/>
        <source>Background mode:</source>
        <translation>ფონის რეჟიმი:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="342"/>
        <source>None</source>
        <translation>არაფერი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Stretch</source>
        <translation>გაწელვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="352"/>
        <source>Zoom</source>
        <translation>მასშტაბი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="357"/>
        <source>Fit</source>
        <translation>ჩატევა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="362"/>
        <source>Center</source>
        <translation>ცენტრი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="277"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>მიუთითეთ, უნდა იყოს თუ არა ფანჯრის დასახატი სიმბოლოები QTerminal-ის მიერ შიდა ფუნქციებით, თუ ეს რენდერის ბიბლიოთეკებისთვის დარჩეს.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="253"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>გადართავს სქელ ფონტის ვარიანტზე ინტენსიური ფერების რენდერისთვის</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="256"/>
        <source>Use bold font face for intense colors</source>
        <translation>სქელი ფონტის გამოყენება ინტენსიური ფერებისთვის</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="529"/>
        <source>&amp;Hide Window Borders</source>
        <translation>ფანჯრის &amp;საზღვრების დამალვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;რომელი ქცევის ემულაცია მოხდება. დაიმახსოვრეთ, რომ შეიძლება, ეს თქვენს ოპერაციულ სისტემისას არა ემთხვდეოდეს.&lt;/p&gt;&lt;p&gt;თუ დარწმუნებული არ ბრძანდებით, გამოიყენეთ &lt;span style=&quot; font-weight:600;&quot;&gt;ნაგულისხმევი&lt;/span&gt; ემულაცია.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>ეს ბრძანება გაეშვება არგუმენტით, რომელიც შეიცავს დროებითი ფაილის სახელს, რომელიც გადახვევის ისტორიას შეიცავს</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="912"/>
        <source>Handle history command</source>
        <translation>ისტორიის დამუშავების ბრძანება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="616"/>
        <location filename="../forms/propertiesdialog.ui" line="630"/>
        <source> px</source>
        <translation> პქს</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Get current size</source>
        <translation>მიმდინარე ზომის მიღება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="859"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>ახალი ჩანართის გახსნა აქტიური ჩანართის მარჯვნივ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="856"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>გამორთულია, ახალი ჩანართი ყველაზე მარვენა ჩანართად გაიხსნება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="546"/>
        <source>Close tab on middle-click</source>
        <translation>თაგუნას შუა ღილაკით ჩანართის დახურვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="821"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>ბრჭყალებში ჩასმის რეჟიმის ძალით გათიშვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="775"/>
        <source>Word selection characters</source>
        <translation>სიმბოლოები სიტყვის მოსანიშნად</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <source>Window</source>
        <translation>ფანჯარა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="246"/>
        <source>Blinking cursor</source>
        <translation>მოციმციმე კურსორი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="421"/>
        <source>Current Terminal</source>
        <translation>მიმდინარე ტერმინალი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Draw a border</source>
        <translation>საზღვრის დახატვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="434"/>
        <source>Set the current terminal on mouseover</source>
        <translation>მიმდინარე ტერმინალის დაყენება თაგუნას გადატარებისას</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="441"/>
        <source>Change window title based on the terminal</source>
        <translation>ფანჯრის სათაურის ცვლილება ტერმინალის მიხედვით</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="448"/>
        <source>Change window icon based on the terminal</source>
        <translation>ფანჯრის ხატულას შეცვლა ტერმინალის მიხედვით</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="597"/>
        <source>Save State when closing</source>
        <translation>მდგომარეობის შენახვა დახურვისას</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>ტექსტის სიტყვებით მონიშვნისას ეს სიმბოლოები სიტყვის ნაწილად ჩაითვლება ალფარიცხვით სიმბოლოებთან ერთად</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="785"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="792"/>
        <source>Mouse cursor hiding delay</source>
        <translation>თაგუნას კურსორის დამალვის დაყოვნება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="799"/>
        <source>No hiding</source>
        <translation>არ დამალო</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="802"/>
        <source> sec</source>
        <translation> წმ</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="818"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>ბრჭყალებში ჩასმული ჩასმის რეჟიმი სასარგებლოა მრავალხაზიანი სტრიქონების ჩასმისთვის.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="842"/>
        <source>Prompt on closing with a running process</source>
        <translation>კითხვა გაშვებული პროცესით დახურვისას</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="866"/>
        <source>Audible bell</source>
        <translation>გასაგონი ზარი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>მალსახმობის ჩასასწორებლად:
1. ორმაგი წკაპი მის ღილაკზე
2. დააჭირეთ სასურველ კომბინაციას და აუშვით
3. დააწკაპუნეთ მალსახმობზე, ან დააჭირეთ ღილაკს Enter

მალსახმობის წასაშლელად/გასათიშად მეორე პუნქტზე, უბრალოდ, მხოლოდ, მოდიფიკატორს დააჭირეთ (მაგ: Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="985"/>
        <source>Shortcut</source>
        <translation>მალმხმობი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="990"/>
        <source>Key</source>
        <translation>გასაღები</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1002"/>
        <source>Show on start</source>
        <translation>ჩვენება გაშვებისას</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1009"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>ჩაკეტვის ღილაკი ნაჩვენებია ჰორიზონტალური ჩანართის ზოლზე</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1012"/>
        <source>Keep window open when it loses focus</source>
        <translation>ფანჯრის ღიად დატოვება მას შემდეგაც კი, რაც ის ფოკუსს დაკარგავს</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>Size</source>
        <translation>ზომა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1030"/>
        <source>Height</source>
        <translation>სიმაღლე</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1040"/>
        <location filename="../forms/propertiesdialog.ui" line="1063"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1053"/>
        <source>Width</source>
        <translation>სიგანე</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1083"/>
        <source>Shortcut:</source>
        <translation>მალსახმობი:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1092"/>
        <source>Note: On Wayland, the shortcut has to be added in the compositor settings for &apos;qterminal -d&apos;.</source>
        <translation>შენიშვნა: Wayland-ზე მალსახმობები კომპოზიტორის მორგების ფანჯრიდან უნდა შეცვალოთ ბრძანებისთვის &apos;qterminal -d&apos;.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1160"/>
        <source>Edit bookmark file contents</source>
        <translation>სანიშნების ფაილის შემცველობის ჩასწორება</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1119"/>
        <source>Enable bookmarks</source>
        <translation>სანიშნეების ჩართვა</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1128"/>
        <source>Bookmark file</source>
        <translation>სანიშნეს ფაილი</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1141"/>
        <source>Find...</source>
        <translation>მოძებნა…</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1150"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>შეგიძლიათ, საკუთარი სანიშნეების ფაილის მდებარეობა ხელით მიუთითოთ. ეს საშუალებას გაძლევთ სანიშნეები გააზიაროთ, მაგალითად, OwnCloud-ით ან Dropbox-ით.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <source>No scrollbar</source>
        <translation>ჩოჩიის გარეშე</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Left</source>
        <translation>მარცხნივ</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Right</source>
        <translation>მარჯვნივ</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Top</source>
        <translation>ზემოთ</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Bottom</source>
        <translation>ქვემოთ</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>BlockCursor</source>
        <translation>ბლოკი</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>UnderlineCursor</source>
        <translation>ხაზგასმული</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>IBeamCursor</source>
        <translation>IBeam</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>No move</source>
        <translation>სვლების გარეშე</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to top</source>
        <translation>ახვევა ზემოთამდე</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to bottom</source>
        <translation>ბოლომდე გადახვევა</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="289"/>
        <source>Examples</source>
        <translation>მაგალითები</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="456"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>გამოსახულებები (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="558"/>
        <source>Open bookmarks file</source>
        <translation>სანიშნეების ფაილის გახსნა</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="560"/>
        <source>XML files (*.xml)</source>
        <translation>XML ფაილები (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="561"/>
        <source>All files (*)</source>
        <translation>ყველა ფაილი (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>Question</source>
        <translation>კითხვა</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>გნებავთ ამ სანიშნეების ფაილის თავზე გადაწერა?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>სანიშნეების ფაილის სახელი არ მთავრდება სტრიქონით &apos;.xml&apos;.
მართლა გნებავთ, თავზე გადააწეროთ?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Warning</source>
        <translation>გაფრთხილება</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>ამ ფაილში სანიშნეების ჩაწერა შეუძლებელია:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="225"/>
        <location filename="../propertiesdialog.cpp" line="342"/>
        <source>System Default</source>
        <translation>სისტემის ნაგულისხმები</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="455"/>
        <source>Choose a background image</source>
        <translation>აირჩიეთ ფონის გამოსახულება</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>სინქრონიზებული სანიშნეები</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="85"/>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Shell No. %1</source>
        <translation>გარემო #%1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Close Subterminal</source>
        <translation>ქვეტერმინალის დახურვა</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Are you sure you want to close this subterminal?</source>
        <translation>მართლა გნებავთ, დახუროთ ეს ქვეტერმინალი?</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="222"/>
        <source>Tab name</source>
        <translation>ჩანართის სახელი</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>New tab name:</source>
        <translation>ახალი ჩანართის სახელი:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="243"/>
        <source>Select new tab title color</source>
        <translation>აირჩიეთ ახალი ჩანართის სათაურის ფერი</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="272"/>
        <source>Close session</source>
        <translation>სესიის დახურვა</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="274"/>
        <source>Change title color</source>
        <translation>სათაურის ფერის შეცვლა</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Close tab</source>
        <translation>ჩანართის დახურვა</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Are you sure you want to close this tab?</source>
        <translation>ნამდვილად გსურთ ამ ჩანართის დახურვა?</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>სესიის ჩატვირთვა</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>შენახული სესიების სია:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>მთავარი ფანჯარა</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="62"/>
        <source>&amp;Session</source>
        <translation>&amp;სესია</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="70"/>
        <source>&amp;Actions</source>
        <translation>&amp;ქმედებები</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="75"/>
        <source>&amp;Help</source>
        <translation>&amp;დახმარება</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="82"/>
        <source>&amp;View</source>
        <translation>&amp;ნახვა</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="87"/>
        <source>&amp;Edit</source>
        <translation>&amp;ჩასწორება</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="103"/>
        <source>&amp;About...</source>
        <translation>&amp;შესახებ...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="108"/>
        <source>About &amp;Qt...</source>
        <translation>&amp;Qt-ის შესახებ...</translation>
    </message>
</context>
</TS>
